package com.gree.mall.manager.logic.workorder;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.date.DateUtil;
import com.google.common.collect.Lists;
import com.gree.mall.manager.bean.admin.AdminUserCom;
import com.gree.mall.manager.bean.es.OrderBase2022Es;
import com.gree.mall.manager.bean.es.OrderBase2023Es;
import com.gree.mall.manager.bean.es.OrderBase2024Es;
import com.gree.mall.manager.bean.es.OrderBaseEs;
import com.gree.mall.manager.bean.workorder.OrderBaseCountBean;
import com.gree.mall.manager.bean.workorder.OrderCount7DayBean;
import com.gree.mall.manager.commonmapper.workorder.OrderBaseCMapper;
import com.gree.mall.manager.enums.OrderStatusEnum;
import com.gree.mall.manager.enums.workorder.OrderBaseStatusEnum;
import com.gree.mall.manager.enums.workorder.OrderTypeEnum;
import com.gree.mall.manager.logic.common.CommonLogic;
import com.gree.mall.manager.plus.entity.PgOrderBase;
import com.gree.mall.manager.plus.service.PgOrderBaseService;
import com.gree.mall.manager.utils.CommonUtils;
import io.swagger.models.auth.In;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import lombok.var;
import org.apache.commons.collections4.CollectionUtils;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.aggregations.AbstractAggregationBuilder;
import org.elasticsearch.search.aggregations.AggregationBuilders;
import org.elasticsearch.search.aggregations.Aggregations;
import org.elasticsearch.search.aggregations.bucket.filter.FilterAggregationBuilder;
import org.elasticsearch.search.aggregations.bucket.filter.ParsedFilter;
import org.elasticsearch.search.aggregations.bucket.histogram.DateHistogramAggregationBuilder;
import org.elasticsearch.search.aggregations.bucket.histogram.DateHistogramInterval;
import org.elasticsearch.search.aggregations.bucket.histogram.Histogram;
import org.elasticsearch.search.aggregations.bucket.histogram.ParsedDateHistogram;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.elasticsearch.core.ElasticsearchRestTemplate;
import org.springframework.data.elasticsearch.core.SearchHits;
import org.springframework.data.elasticsearch.core.query.FetchSourceFilter;
import org.springframework.data.elasticsearch.core.query.NativeSearchQuery;
import org.springframework.data.elasticsearch.core.query.NativeSearchQueryBuilder;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestParam;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Service
@RequiredArgsConstructor
public class OrderBaseCountLogic {

    private final OrderBaseCMapper orderBaseCMapper;
    private final PgOrderBaseService pgOrderBaseService;
    private final CommonLogic commonLogic;
    private final ElasticsearchRestTemplate elasticsearchRestTemplate;

    /**
     * 首页工单统计
     * @return
     */
    public OrderBaseCountBean baseCountBean( String startTime,
                                             String endTime,
                                             HttpServletRequest request){
        AdminUserCom adminUser = commonLogic.getAdminUser();
        String year = CommonUtils.getYear(request);
        OrderBaseCountBean orderBaseCountBean = new OrderBaseCountBean();
        BoolQueryBuilder queryBuilderCount = QueryBuilders.boolQuery();

        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty(adminUser.getAdminWebsitIds())) {
            queryBuilderCount.must(
                    QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("create_websit_id", adminUser.getAdminWebsitIds()))
                            .should(QueryBuilders.termsQuery("websit_id", adminUser.getAdminWebsitIds()))
            );
        }

        if (startTime != null){
            queryBuilderCount.must(QueryBuilders.rangeQuery("create_time")
                    .gte(startTime)
                    .lte(endTime)
            );
        }

        //待派工
        NativeSearchQuery searchQueryDPG = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderCount)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(this.getAggs(AggregationBuilders.filter("DPG", QueryBuilders.boolQuery()
                        .must(QueryBuilders.termsQuery("order_status","DSHPG","CJ","YPD","DXSPD","DZBPG","DWDSPGP","DXSSPGP","DTJXSSPGP","DZBSPGP","DFZXPD","DFZXSPGP","DWDPG","DWDPD")
                ))))
                .build();
        SearchHits responseDPG = this.search(searchQueryDPG,year);

        orderBaseCountBean.setDpg(Convert.toInt(this.getWorkerOrderCountResult(responseDPG.getAggregations(),"DPG")));


        //待接收
        NativeSearchQuery searchQueryDJS = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderCount)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(this.getAggs(AggregationBuilders.filter("DJS", QueryBuilders.boolQuery()
                        .must(QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("is_meet", false))
                                .should(QueryBuilders.termsQuery("order_status", "DJD")))
                        .mustNot(QueryBuilders.termsQuery("order_status", "YQX", "FWQX", "FL", "FWZT", "YCGB","YZP"))
                )))
                .build();
        SearchHits responseDJS = this.search(searchQueryDJS,year);

        orderBaseCountBean.setDjs(Convert.toInt(this.getWorkerOrderCountResult(responseDJS.getAggregations(),"DJS")));


        //待抢单
        NativeSearchQuery searchQueryDQD = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderCount)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(this.getAggs(AggregationBuilders.filter("DQD", QueryBuilders.boolQuery()
                        .must(QueryBuilders.termsQuery("order_status","DQD")
                        ))))
                .build();
        SearchHits responseDQD = this.search(searchQueryDQD,year);

        orderBaseCountBean.setDqd(Convert.toInt(this.getWorkerOrderCountResult(responseDQD.getAggregations(),"DQD")));


        //服务中
        NativeSearchQuery searchQueryfwz = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderCount)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(this.getAggs(AggregationBuilders.filter("fwz", QueryBuilders.boolQuery()
                        .must(QueryBuilders.termsQuery("order_status","FWZ","GCSZT","BFWG","DSM","WDBH","XSBH","TJXSBH","ZBBH","FZXBH")
                        ))))
                .build();
        SearchHits responsefwz = this.search(searchQueryfwz,year);

        orderBaseCountBean.setFwz(Convert.toInt(this.getWorkerOrderCountResult(responsefwz.getAggregations(),"fwz")));


        //待预约
        NativeSearchQuery searchQueryDYY = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderCount)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(this.getAggs(AggregationBuilders.filter("DYY", QueryBuilders.boolQuery()
                        .mustNot(QueryBuilders.termsQuery("order_status","YWG","GCSZX","WDWG","YWGO","YQX","FWZT","YCGB","YZP",
                                "FWQX","FL","YJS","LRCD","DSHPG","CJ","YPD","DXSPD","DZBPG","DWDSPGP","DXSSPGP","DTJXSSPGP","DZBSPGP")
                        )
                        .mustNot(QueryBuilders.existsQuery("appointment_time"))
                )))
                .build();
        SearchHits responseDYY = this.search(searchQueryDYY,year);

        orderBaseCountBean.setDyy(Convert.toInt(this.getWorkerOrderCountResult(responseDYY.getAggregations(),"DYY")));

        //异常单处理
        NativeSearchQuery searchQueryYCDCL = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderCount)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(this.getAggs(AggregationBuilders.filter("YCDCL", QueryBuilders.boolQuery()
                        .mustNot(QueryBuilders.termsQuery("order_status","YWG","YWGO","YJS"))
                        .must(QueryBuilders.termsQuery("is_exception",true))

                )))
                .build();
        SearchHits responseYCDCL = this.search(searchQueryYCDCL,year);

        orderBaseCountBean.setYcdcl(Convert.toInt(this.getWorkerOrderCountResult(responseYCDCL.getAggregations(),"YCDCL")));


        //差评
        NativeSearchQuery searchQueryCP = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderCount)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(this.getAggs(AggregationBuilders.filter("CP", QueryBuilders.boolQuery()
                        .must(QueryBuilders.termsQuery("appraise_status","C"))

                )))
                .build();
        SearchHits responseCP = this.search(searchQueryCP,year);

        orderBaseCountBean.setCp(Convert.toInt(this.getWorkerOrderCountResult(responseCP.getAggregations(),"CP")));


        Map<String,List<Long>> qtddqs = new HashMap<>();

        List<Long> xzgdList = new ArrayList<>();
        List<Long> wgdList = new ArrayList<>();
        List<Long> jxzList = new ArrayList<>();
        List<Long> qtsmList = new ArrayList<>();

        List<String> orderStatus = new ArrayList<>
                ();

        orderStatus.add("YWG");
        orderStatus.add("GCSZX");
        orderStatus.add("WDWG");
        orderStatus.add("YWGO");
        orderStatus.add("YJS");
        orderStatus.add("LRCD");

        List<String> orderStatusQx = new ArrayList<>();
        orderStatusQx.add("YQX");
        orderStatusQx.add("FWZT");
        orderStatusQx.add("YCGB");
        orderStatusQx.add("FWQX");
        orderStatusQx.add("FL");
        orderStatusQx.add("YZP");

        BoolQueryBuilder queryBuilder = QueryBuilders.boolQuery();

        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty(adminUser.getAdminWebsitIds())) {
            queryBuilder.must(
                    QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("create_websit_id", adminUser.getAdminWebsitIds()))
                            .should(QueryBuilders.termsQuery("websit_id", adminUser.getAdminWebsitIds()))
            );
        }
        queryBuilder.must(
                QueryBuilders.rangeQuery("create_time")
                        .gte(DateUtil.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), (-6))),"yyyy-MM-dd HH:mm:ss"))
                        .lte(DateUtil.format(new Date(),"yyyy-MM-dd HH:mm:ss")));

        NativeSearchQuery searchQueryDay = new NativeSearchQueryBuilder()
                .withQuery(queryBuilder)
                .withSourceFilter(new FetchSourceFilter(new String[]{"create_time"}, null))
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(AggregationBuilders.dateHistogram("xzgd")
                        .field("create_time")
                        .calendarInterval(DateHistogramInterval.DAY)
                        .format("yyyy-MM-dd"))
                .build();


        // 执行查询并获取聚合结果
        SearchHits<OrderBaseEs> searchHitsXZGD = this.search(searchQueryDay,year);

        var aggregationsXZGD = searchHitsXZGD.getAggregations();

        if (aggregationsXZGD != null) {
            ParsedDateHistogram dateHistogram = aggregationsXZGD.get("xzgd");
            List<? extends Histogram.Bucket> buckets = dateHistogram.getBuckets();

            // 遍历每天的统计结果
            for (Histogram.Bucket bucket : buckets) {
                String date = bucket.getKeyAsString();
                long count = bucket.getDocCount();
                xzgdList.add(count);
            }
        }

        BoolQueryBuilder queryBuilderWGD = QueryBuilders.boolQuery();

        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty(adminUser.getAdminWebsitIds())) {
            queryBuilderWGD.must(
                    QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("create_websit_id", adminUser.getAdminWebsitIds()))
                            .should(QueryBuilders.termsQuery("websit_id", adminUser.getAdminWebsitIds()))
            );
        }
        queryBuilderWGD.must(
        QueryBuilders.boolQuery()
                .must(QueryBuilders.termsQuery("order_status",orderStatus))
                .must(  QueryBuilders.rangeQuery("over_time")
                        .gte(DateUtil.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), (-6))),"yyyy-MM-dd HH:mm:ss"))
                        .lte(DateUtil.format(new Date(),"yyyy-MM-dd HH:mm:ss")))
        );


        NativeSearchQuery searchQueryWGD = new NativeSearchQueryBuilder()
                .withQuery(queryBuilderWGD)
                .withSourceFilter(new FetchSourceFilter(new String[]{"create_time"}, null))
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(AggregationBuilders.dateHistogram("WGD")
                        .field("over_time")
                        .calendarInterval(DateHistogramInterval.DAY)
                        .format("yyyy-MM-dd"))
                .build();


        // 执行查询并获取聚合结果
        SearchHits<OrderBaseEs> searchHitsXWGD = this.search(searchQueryWGD,year);

        var aggregationsWGD = searchHitsXWGD.getAggregations();

        if (aggregationsWGD != null) {
            ParsedDateHistogram dateHistogram = aggregationsWGD.get("WGD");
            List<? extends Histogram.Bucket> buckets = dateHistogram.getBuckets();

            // 遍历每天的统计结果
            for (Histogram.Bucket bucket : buckets) {
                String date = bucket.getKeyAsString();
                long count = bucket.getDocCount();
                wgdList.add(count);
            }
        }

        BoolQueryBuilder queryBuilderJXZ = QueryBuilders.boolQuery();

        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty(adminUser.getAdminWebsitIds())) {
            queryBuilderJXZ.must(
                    QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("create_websit_id", adminUser.getAdminWebsitIds()))
                            .should(QueryBuilders.termsQuery("websit_id", adminUser.getAdminWebsitIds()))
            );
        }
        queryBuilderJXZ.must(
                QueryBuilders.rangeQuery("create_time")
                        .gte(DateUtil.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), (-6))),"yyyy-MM-dd HH:mm:ss"))
                        .lte(DateUtil.format(new Date(),"yyyy-MM-dd HH:mm:ss")));

        queryBuilderJXZ.mustNot(QueryBuilders.termsQuery("order_status",orderStatus))
                .mustNot(QueryBuilders.termsQuery("order_status",orderStatusQx));

        NativeSearchQuery searchQueryJXZ= new NativeSearchQueryBuilder()
                .withQuery(queryBuilderJXZ)
                .withSourceFilter(new FetchSourceFilter(new String[]{"create_time"}, null))
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(AggregationBuilders.dateHistogram("JXZ")
                        .field("create_time")
                        .calendarInterval(DateHistogramInterval.DAY)
                        .format("yyyy-MM-dd"))
                .build();


        // 执行查询并获取聚合结果
        SearchHits<OrderBaseEs> searchHitsJXZ= this.search(searchQueryJXZ,year);

        var aggregationsJXZ = searchHitsJXZ.getAggregations();

        if (aggregationsJXZ != null) {
            ParsedDateHistogram dateHistogram = aggregationsJXZ.get("JXZ");
            List<? extends Histogram.Bucket> buckets = dateHistogram.getBuckets();

            // 遍历每天的统计结果
            for (Histogram.Bucket bucket : buckets) {
                String date = bucket.getKeyAsString();
                long count = bucket.getDocCount();
                jxzList.add(count);
            }
        }

        qtddqs.put("新增工单",xzgdList);
        qtddqs.put("完工工单",wgdList);
        qtddqs.put("进行中",jxzList);

        orderBaseCountBean.setQtddqs(qtddqs);


        BoolQueryBuilder queryBuilderQTSM = QueryBuilders.boolQuery();

        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty(adminUser.getAdminWebsitIds())) {
            queryBuilderQTSM.must(
                    QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("create_websit_id", adminUser.getAdminWebsitIds()))
                            .should(QueryBuilders.termsQuery("websit_id", adminUser.getAdminWebsitIds()))
            );
        }

        queryBuilderQTSM.must(
                QueryBuilders.rangeQuery("appointment_time")
                        .gte(DateUtil.format(DateUtil.beginOfDay(new Date()),"yyyy-MM-dd HH:mm:ss"))
                        .lte(DateUtil.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), (7))),"yyyy-MM-dd HH:mm:ss")));


        NativeSearchQuery searchQueryQTSM= new NativeSearchQueryBuilder()
                .withQuery(queryBuilderQTSM)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(AggregationBuilders.dateHistogram("QTDSM")
                        .field("appointment_time")
                        .calendarInterval(DateHistogramInterval.DAY)
                        .format("yyyy-MM-dd"))
                .build();
        SearchHits responseQTSM = this.search(searchQueryQTSM,year);

        var aggregationsQTSM = responseQTSM.getAggregations();

        if (aggregationsQTSM != null) {
            ParsedDateHistogram dateHistogram = aggregationsQTSM.get("QTDSM");
            List<? extends Histogram.Bucket> buckets = dateHistogram.getBuckets();

            // 遍历每天的统计结果
            for (Histogram.Bucket bucket : buckets) {
                String date = bucket.getKeyAsString();
                long count = bucket.getDocCount();
                qtsmList.add(count);
            }
        }



        orderBaseCountBean.setQtsm(qtsmList);

        List<String> collect = new ArrayList<>();

        collect.add(OrderTypeEnum.INSTALL.getRemark());
        collect.add(OrderTypeEnum.REPAIR.getRemark());

        Map<String,List<Long>> wglxfb = new HashMap<>();


        BoolQueryBuilder queryBuilderAZ = QueryBuilders.boolQuery();

        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty(adminUser.getAdminWebsitIds())) {
            queryBuilderAZ.must(
                    QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("create_websit_id", adminUser.getAdminWebsitIds()))
                            .should(QueryBuilders.termsQuery("websit_id", adminUser.getAdminWebsitIds()))
            );
        }

        queryBuilderAZ.must(
                QueryBuilders.termsQuery("order_type_text",OrderTypeEnum.INSTALL.getRemark()));

        queryBuilderAZ.must(
                QueryBuilders.rangeQuery("over_time")
                        .gte(DateUtil.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), (-29))),"yyyy-MM-dd HH:mm:ss"))
                        .lte(DateUtil.format(DateUtil.endOfDay(new Date()),"yyyy-MM-dd HH:mm:ss")));


        NativeSearchQuery searchQueryAZ= new NativeSearchQueryBuilder()
                .withQuery(queryBuilderAZ)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(AggregationBuilders.dateHistogram("AZ")
                        .field("over_time")
                        .calendarInterval(DateHistogramInterval.DAY)
                        .format("yyyy-MM-dd"))
                .build();
        SearchHits responseAZ = this.search(searchQueryAZ,year);

        var aggregationsAZ = responseAZ.getAggregations();

        if (aggregationsAZ != null) {
            ParsedDateHistogram dateHistogram = aggregationsAZ.get("AZ");
            List<? extends Histogram.Bucket> buckets = dateHistogram.getBuckets();
            List<Long> list = new ArrayList<>();
            // 遍历每天的统计结果
            for (Histogram.Bucket bucket : buckets) {
                String date = bucket.getKeyAsString();
                long count = bucket.getDocCount();
                list.add(count);
            }

            wglxfb.put(OrderTypeEnum.INSTALL.getRemark(),list);
        }


        BoolQueryBuilder queryBuilderWX = QueryBuilders.boolQuery();

        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty(adminUser.getAdminWebsitIds())) {
            queryBuilderWX.must(
                    QueryBuilders.boolQuery().should(QueryBuilders.termsQuery("create_websit_id", adminUser.getAdminWebsitIds()))
                            .should(QueryBuilders.termsQuery("websit_id", adminUser.getAdminWebsitIds()))
            );
        }
        queryBuilderWX.must(QueryBuilders.termsQuery("order_type_text",OrderTypeEnum.REPAIR.getRemark()));

        queryBuilderWX.must(QueryBuilders.rangeQuery("over_time")
                .gte(DateUtil.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), (-29))),"yyyy-MM-dd HH:mm:ss"))
                .lte(DateUtil.format(DateUtil.endOfDay(new Date()),"yyyy-MM-dd HH:mm:ss")));

        NativeSearchQuery searchQueryWX= new NativeSearchQueryBuilder()
                .withQuery(queryBuilderWX)
                .withPageable(PageRequest.of(1, 1))
                .addAggregation(AggregationBuilders.dateHistogram("WX")
                        .field("over_time")
                        .calendarInterval(DateHistogramInterval.DAY)
                        .format("yyyy-MM-dd"))
                .build();
        SearchHits responseWX = this.search(searchQueryWX,year);

        var aggregationsWX = responseWX.getAggregations();

        if (aggregationsWX != null) {
            ParsedDateHistogram dateHistogram = aggregationsWX.get("WX");
            List<? extends Histogram.Bucket> buckets = dateHistogram.getBuckets();
            List<Long> list = new ArrayList<>();
            // 遍历每天的统计结果
            for (Histogram.Bucket bucket : buckets) {
                String date = bucket.getKeyAsString();
                long count = bucket.getDocCount();
                list.add(count);
            }

            wglxfb.put(OrderTypeEnum.REPAIR.getRemark(),list);
        }


        orderBaseCountBean.setWglxfb(wglxfb);

        return orderBaseCountBean;
    }

    private SearchHits search(NativeSearchQuery searchQuery,String year) {

        if (year.equals("2023")) {
            SearchHits response = elasticsearchRestTemplate.search(searchQuery, OrderBase2023Es.class);
            return response;
        }
        if (year.equals("2024")) {
            SearchHits response = elasticsearchRestTemplate.search(searchQuery, OrderBase2024Es.class);
            return response;
        }

        if (year.equals("2022") || Convert.toInt(year) < 2022) {
            SearchHits response = elasticsearchRestTemplate.search(searchQuery, OrderBase2022Es.class);
            return response;
        }else {
            SearchHits response = elasticsearchRestTemplate.search(searchQuery, OrderBaseEs.class);
            return response;
        }
    }


    public AbstractAggregationBuilder<?> getAggs(FilterAggregationBuilder filter) {
        return filter.subAggregation(AggregationBuilders.sum("total_mac_sum").field("total_num"))
                .subAggregation(AggregationBuilders.terms("order_type_group").field("order_type")
                        .subAggregation(AggregationBuilders.sum("mac_sum").field("total_num")));
    }

    public long getWorkerOrderCountResult(Aggregations aggregations, String name) {
        StringBuffer sb = new StringBuffer();
        ParsedFilter parsedFilter = aggregations.get(name);
        //总服务单数
        long totalOrderNums = parsedFilter.getDocCount();

        return totalOrderNums;
    }

    /**
     * 统计近7天的订单趋势和需上门数量
     * @return
     */
//    public OrderCount7DayBean last7DayCount(){
//        AdminUserCom adminUser = commonLogic.getAdminUser();
//        OrderCount7DayBean orderCount7DayBean = new OrderCount7DayBean();
//
//        SimpleDateFormat sdf = new SimpleDateFormat("MM-dd");
//        //最近7天的日期
//        orderCount7DayBean.setDates(
//            Lists.newArrayList(
//                    sdf.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(),0))),
//                    sdf.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(),1))),
//                    sdf.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(),2))),
//                    sdf.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(),3))),
//                    sdf.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(),4))),
//                    sdf.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(),5))),
//                    sdf.format(DateUtil.beginOfDay(DateUtil.offsetDay(new Date(),6))))
//        );
//
//        //最近7天的制单时间 key = time,total
//        List<Map<String,Long>> countList1 = orderBaseCMapper.countLast7Day1(adminUser.getCompanyWechatId(), adminUser.getAdminWebsitIds());
//        List<Map<String,Long>> countList2 = orderBaseCMapper.countLast7Day1(adminUser.getCompanyWechatId(), adminUser.getAdminWebsitIds());
//
//        return orderCount7DayBean;
//    }

    /**
     * 未来7天需上门数量
     * @return
     */
//    public OrderCount7DayBean feature7DayCount(){
//        AdminUserCom adminUser = commonLogic.getAdminUser();
//        OrderCount7DayBean orderCount7DayBean = new OrderCount7DayBean();
//
//        SimpleDateFormat sdf = new SimpleDateFormat("MM-dd");
//        return orderCount7DayBean;
//    }

}
